@@ -602,10 +602,8 @@ chxj_qr_code_handler(request_rec *r)
   /* ⤷᡼ѴϥɥǤСǤϽʤ                 */
   /*--------------------------------------------------------------------------*/
   conf = chxj_get_module_config(r->per_dir_config, &chxj_module);
-  if (!conf || conf->image == CHXJ_IMG_ON) {
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+  if (!conf || conf->image == CHXJ_IMG_ON)
     return DECLINED;
-  }
 
   memset(&doc, 0, sizeof(Doc));
   memset(&qrcode, 0, sizeof(qr_code_t));
@@ -778,7 +776,7 @@ chxj_qrcode_create_image_data(
     goto on_error;
 
 #ifdef QR_CODE_DEBUG
-  DBG(r,"REQ[%X] convert to jpg", TO_ADDR(r));
+  DBG(r,"REQ[%X] convert to jpg",TO_ADDR(r));
 #endif
 
   tmp = (unsigned char*)MagickGetImageBlob(magick_wand,img_len);
@@ -798,9 +796,6 @@ chxj_qrcode_create_image_data(
 
 on_error:
   EXIT_MAGICK_ERROR();
-#ifdef QR_CODE_DEBUG
-  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
-#endif
   return HTTP_NOT_FOUND;
 }
 
@@ -830,7 +825,7 @@ chxj_qr_code(qr_code_t *qrcode, char *module[])
     /*------------------------------------------------------------------------*/
     binstr = apr_psprintf(r->pool, "%s", s_get_mode_spec(qrcode));
 #ifdef QR_CODE_DEBUG
-    DBG(r,"REQ[%X] s_get_mode_spec()", TO_ADDR(r));
+    DBG(r,"REQ[%X] s_get_mode_spec()",TO_ADDR(r));
 #endif
 
     /*------------------------------------------------------------------------*/
@@ -839,7 +834,7 @@ chxj_qr_code(qr_code_t *qrcode, char *module[])
     binstr = apr_pstrcat(r->pool, binstr, 
                   s_get_char_bit_count(qrcode, strlen(qrcode->indata)), NULL);
 #ifdef QR_CODE_DEBUG
-    DBG(r, "REQ[%X] s_get_char_bit_count()[%s]", TO_ADDR(r), binstr);
+    DBG(r,"REQ[%X] s_get_char_bit_count()[%s]", TO_ADDR(r),binstr);
 #endif
 
     /*------------------------------------------------------------------------*/
@@ -847,7 +842,7 @@ chxj_qr_code(qr_code_t *qrcode, char *module[])
     /*------------------------------------------------------------------------*/
     data_code_count = v_data_code_count[qrcode->version][qrcode->level];
 #ifdef QR_CODE_DEBUG
-    DBG(r,"REQ[%X] data_code_count=[%d]", TO_ADDR(r), data_code_count);
+    DBG(r,"REQ[%X] data_code_count=[%d]", TO_ADDR(r),data_code_count);
 #endif
 
     /*------------------------------------------------------------------------*/
@@ -893,8 +888,8 @@ chxj_qr_code(qr_code_t *qrcode, char *module[])
     }
   }
 #ifdef QR_CODE_DEBUG
-  DBG(r,"REQ[%X] After TERM BIT[%s] len[%d]bit [%f]byte", TO_ADDR(r), binstr, strlen(binstr), (float)(((float)strlen(binstr))/8.0));
-  DBG(r,"REQ[%X] add term data", TO_ADDR(r));
+  DBG(r,"REQ[%X] After TERM BIT[%s] len[%d]bit [%f]byte", TO_ADDR(r),binstr, strlen(binstr), (float)(((float)strlen(binstr))/8.0));
+  DBG(r,"REQ[%X] add term data",TO_ADDR(r));
 #endif
 
   /*--------------------------------------------------------------------------*/
@@ -902,8 +897,8 @@ chxj_qr_code(qr_code_t *qrcode, char *module[])
   /*--------------------------------------------------------------------------*/
   binstr = s_tidy_8bit_code(qrcode, binstr, data_code_count);
 #ifdef QR_CODE_DEBUG
-  DBG(r,"REQ[%X] After Tidy 8 BIT[%s]", TO_ADDR(r), binstr);
-  DBG(r,"REQ[%X] s_tidy_8bit_code()", TO_ADDR(r));
+  DBG(r,"REQ[%X] After Tidy 8 BIT[%s]", TO_ADDR(r),binstr);
+  DBG(r,"REQ[%X] s_tidy_8bit_code()",TO_ADDR(r));
 #endif
 
   /*--------------------------------------------------------------------------*/
@@ -911,7 +906,7 @@ chxj_qr_code(qr_code_t *qrcode, char *module[])
   /*--------------------------------------------------------------------------*/
   decstr = s_str_to_bin(qrcode, binstr, data_code_count);
 #ifdef QR_CODE_DEBUG
-  DBG(r,"REQ[%X] s_str_to_bin()", TO_ADDR(r));
+  DBG(r,"REQ[%X] s_str_to_bin()",TO_ADDR(r));
 #endif
 
 #ifdef QR_CODE_DEBUG
@@ -923,7 +918,7 @@ chxj_qr_code(qr_code_t *qrcode, char *module[])
     for (ii=0; ii<data_code_count; ii++) {
       rows = apr_pstrcat(r->pool, rows, apr_psprintf(r->pool, "[%02x]\n", (unsigned char)decstr[ii]), NULL);
     }
-    DBG(r,"REQ[%X] decstr[%s]", TO_ADDR(r), rows);
+    DBG(r,"REQ[%X] decstr[%s]", TO_ADDR(r),rows);
   }while(0);
 #endif
 
@@ -1276,7 +1271,7 @@ s_get_char_bit_count(qr_code_t *qrcode, int len)
   char *result;
   int data_capacity   = v_capacity_table[qrcode->version*4+qrcode->level].size[qrcode->mode];
 
-  DBG(qrcode->r, "REQ[%X] len [%d]", TO_ADDR(qrcode->r),len);
+  DBG(qrcode->r,"REQ[%X] len [%d]", TO_ADDR(qrcode->r),len);
   if (qrcode->mode == QR_KANJI_MODE && data_capacity * 2 < len) {
     len = data_capacity * 2;
   }
@@ -1307,7 +1302,7 @@ s_get_char_bit_count(qr_code_t *qrcode, int len)
   result[bit_count] = '\0';
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "REQ[%X] Character Count bit [%s]", TO_ADDR(qrcode->r),result);
+  DBG(qrcode->r,"REQ[%X] Character Count bit [%s]", TO_ADDR(qrcode->r),result);
 #endif
 
   return result;
@@ -1332,7 +1327,7 @@ s_data_to_bin_num(qr_code_t *qrcode, int UNUSED(data_code_count))
   int data_capacity   = v_capacity_table[qrcode->version*4+qrcode->level].size[qrcode->mode];
 
   if (data_capacity < len) {
-    DBG(qrcode->r, "REQ[%X] input data is too long", TO_ADDR(qrcode->r));
+    DBG(qrcode->r, "REQ[%X] input data is too long",TO_ADDR(qrcode->r));
     len = data_capacity;
   }
   setn = len / 3;
@@ -1402,7 +1397,7 @@ s_data_to_bin_alpha(qr_code_t *qrcode, int UNUSED(data_code_count))
   int data_capacity   = v_capacity_table[qrcode->version*4+qrcode->level].size[qrcode->mode];
 
   if (data_capacity < len) {
-    DBG(qrcode->r, "REQ[%X] input data is too long", TO_ADDR(qrcode->r));
+    DBG(qrcode->r, "REQ[%X] input data is too long",TO_ADDR(qrcode->r));
     len = data_capacity;
   }
   setn = len / 2;
@@ -1544,7 +1539,7 @@ s_data_to_bin_8bit(qr_code_t *qrcode, int UNUSED(data_code_count))
   int data_capacity   = v_capacity_table[qrcode->version*4+qrcode->level].size[qrcode->mode];
 
   if (data_capacity < len) {
-    DBG(qrcode->r, "REQ[%X] input data is too long", TO_ADDR(qrcode->r));
+    DBG(qrcode->r, "REQ[%X] input data is too long",TO_ADDR(qrcode->r));
     len = data_capacity;
   }
 
@@ -1568,7 +1563,7 @@ s_data_to_bin_8bit(qr_code_t *qrcode, int UNUSED(data_code_count))
   result[kk] = 0;
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "REQ[%X] input data --> 2bin result[%s] len:[%d]", TO_ADDR(qrcode->r), result, strlen(result));
+  DBG(qrcode->r,"REQ[%X] input data --> 2bin result[%s] len:[%d]", TO_ADDR(qrcode->r),result, strlen(result));
 #endif
 
   return result;
@@ -1591,12 +1586,12 @@ s_data_to_bin_kanji(qr_code_t *qrcode, int UNUSED(data_code_count))
   int data_capacity   = v_capacity_table[qrcode->version*4+qrcode->level].size[qrcode->mode];
 
   if (data_capacity * 2 < len) {
-    DBG(qrcode->r, "REQ[%X] input data is too long", TO_ADDR(qrcode->r));
+    DBG(qrcode->r, "REQ[%X] input data is too long",TO_ADDR(qrcode->r));
     len = data_capacity * 2;
   }
 
   if ((len % 2) != 0) {
-    DBG(qrcode->r, "REQ[%X] invalid data.", TO_ADDR(qrcode->r));
+    DBG(qrcode->r,"REQ[%X] invalid data.",TO_ADDR(qrcode->r));
     qrcode->mode_change = QR_CHANGE;
     qrcode->mode        = QR_8BIT_MODE;
     return NULL;
@@ -1646,7 +1641,7 @@ s_data_to_bin_kanji(qr_code_t *qrcode, int UNUSED(data_code_count))
   result[kk] = 0;
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "REQ[%X] input data --> 2bin result[%s] len:[%d]", TO_ADDR(qrcode->r), result, strlen(result));
+  DBG(qrcode->r,"REQ[%X] input data --> 2bin result[%s] len:[%d]", TO_ADDR(qrcode->r),result, strlen(result));
 #endif
 
   return result;
@@ -1666,7 +1661,7 @@ s_tidy_8bit_code(qr_code_t *qrcode, const char *indata, int data_code_count)
   char *result;
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "REQ[%X] len[%d] data_code_count * 8 [%d]", TO_ADDR(qrcode->r),len, data_code_count * 8);
+  DBG(qrcode->r,"REQ[%X] len[%d] data_code_count * 8 [%d]", TO_ADDR(qrcode->r),len, data_code_count * 8);
 #endif
 
   assert (len <= data_code_count * 8);
@@ -1700,7 +1695,7 @@ s_tidy_8bit_code(qr_code_t *qrcode, const char *indata, int data_code_count)
   }
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "REQ[%X] tidy len[%d] data_code_count[%d]", TO_ADDR(qrcode->r), strlen(result)/8, data_code_count);
+  DBG(qrcode->r,"REQ[%X] tidy len[%d] data_code_count[%d]", TO_ADDR(qrcode->r),strlen(result)/8, data_code_count);
 #endif
 
   return result;
@@ -1742,9 +1737,9 @@ s_init_modules(qr_code_t *qrcode, qr_mask_pattern_t pat, char *dst[])
   int yy;
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r,"REQ[%X] end %s()",TO_ADDR(qrcode->r),__func__);
-
-  DBG(qrcode->r,"REQ[%X] module_count[%d]", TO_ADDR(qrcode->r),module_count);
+  request_rec *r = qrcode->r;
+  DBG(qrcode->r,"REQ[%X] start %s()",TO_ADDR(qrcode->r),__func__);
+  DBG(qrcode->r,"REQ[%X] module_count[%d]", TO_ADDR(r),module_count);
 #endif
 
   for (yy=0; yy<module_count; yy++)
@@ -1759,7 +1754,7 @@ s_init_modules(qr_code_t *qrcode, qr_mask_pattern_t pat, char *dst[])
   s_setup_version_info(qrcode, dst);
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r,"REQ[%X] end %s()",TO_ADDR(qrcode->r),__func__);
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
 #endif
 
 }
@@ -1774,8 +1769,9 @@ s_setup_probe_position(qr_code_t *qrcode, char *dst[], int pos_x, int pos_y)
   int xx;
   int yy;
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r,"REQ[%X] end %s()",TO_ADDR(qrcode->r),__func__);
-  DBG(qrcode->r,"REQ[%X] module_count[%d]", TO_ADDR(qrcode->r),module_count);
+  request_rec *r = qrcode->r;
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
+  DBG(r,"REQ[%X] module_count[%d]", TO_ADDR(r),module_count);
 #endif
 
   for (yy=-1; yy<=7; yy++) {
@@ -1830,7 +1826,7 @@ s_setup_probe_position(qr_code_t *qrcode, char *dst[], int pos_x, int pos_y)
     }
   }
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r,"REQ[%X] end %s()",TO_ADDR(qrcode->r),__func__);
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
 #endif
 }
 /* 
@@ -1842,8 +1838,9 @@ s_setup_timing_pattern(qr_code_t *qrcode, char *dst[])
   int module_count = v_module_count_table[qrcode->version];
   int xx, yy;
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r,"REQ[%X] start %s()",TO_ADDR(qrcode->r),__func__);
-  DBG(qrcode->r,"REQ[%X] module_count[%d]", TO_ADDR(qrcode->r),module_count);
+  request_rec *r = qrcode->r;
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
+  DBG(r,"REQ[%X] module_count[%d]", TO_ADDR(r),module_count);
 #endif
 
   yy=6;
@@ -1869,7 +1866,7 @@ s_setup_timing_pattern(qr_code_t *qrcode, char *dst[])
   }
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r,"REQ[%X] end %s()",TO_ADDR(qrcode->r),__func__);
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
 #endif
 }
 
@@ -1886,7 +1883,8 @@ s_setup_position_adjust(qr_code_t *qrcode, char *dst[])
   int dxx, dyy;
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "start s_setup_position_adjust()");
+  request_rec *r = qrcode->r;
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
 #endif
 
   for (yy=0; yy<7; yy++) {
@@ -1922,7 +1920,7 @@ s_setup_position_adjust(qr_code_t *qrcode, char *dst[])
   }
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "end s_setup_position_adjust()");
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
 #endif
 }
 
@@ -1938,8 +1936,9 @@ s_setup_type_info(qr_code_t *qrcode, char *dst[], qr_mask_pattern_t pat)
   int yy;
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "start s_setup_type_info()");
-  DBG(qrcode->r, "module_count[%d]", module_count);
+  request_rec *r = qrcode->r;
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
+  DBG(r,"REQ[%X] module_count[%d]", TO_ADDR(r),module_count);
 #endif
 
   /* ǡ */
@@ -2008,7 +2007,7 @@ s_setup_type_info(qr_code_t *qrcode, char *dst[], qr_mask_pattern_t pat)
   dst[module_count - 8][8] = '1';
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "start s_setup_type_info()");
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
 #endif
 }
 
@@ -2065,9 +2064,10 @@ s_map_data(qr_code_t     *qrcode,
   int mask;
 
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "start s_map_data()");
-  DBG(qrcode->r, "module_count[%d]", module_count);
-  DBG(qrcode->r, "data_count[%d]", data_count);
+  request_rec *r = qrcode->r;
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
+  DBG(r,"REQ[%X] module_count[%d]",TO_ADDR(r),module_count);
+  DBG(r,"REQ[%X] data_count[%d]",TO_ADDR(r),data_count);
 #endif
   in_pos = 0;
   now_bit = 7;
@@ -2125,7 +2125,7 @@ s_map_data(qr_code_t     *qrcode,
     }
   }
 #ifdef QR_CODE_DEBUG
-  DBG(qrcode->r, "end s_map_data()");
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
 #endif
 }
 
